#ifndef ARATEK_H
#define ARATEK_H

typedef void *HANDLE;

#pragma pack(1)
typedef struct
{
  char version[4];
  char manufacture[12];
  char product_name[30];
  char product_model[12];
  char hardware_version[2];
  char bootloader_version[4];
  char firmware_version[4];
  char serial_number[20];
  unsigned short image_width;
  unsigned short image_height; 
  char produced_date_time[8];
  unsigned short mode_id;
  unsigned short dpi;
  char isUSBSupported;
  char isUARTSupported;
  char isSPISupported; 
  char isSoftwareLicenseInforTrustMe;
  char isSoftwareLicenseInforTrustAFIS;
  char isSoftwareLicenseInforTrustLink;
  char isSoftwareLicenseInforTrustChinaOS;
  char isSoftwareLicenseInforReserved0;
  char isSoftwareLicenseInforReserved1;
  unsigned char reserved[911];
} ARAFP_DevDesc;
#pragma pack()


#define FEATURE_LENGTH    (20 * 1024)

enum
{
  GEN_SUCCEDED = 0,		//Succeed
  GEN_PARAM_NULL=10,    //参数内存分配为空
  GEN_PAR_ERR = -900,		//Wrong parameter(s)
  //GEN_MEM_ERR = -901,		//Memory leak, failed to allocate space
  //GEN_FUC_FAIL = -902,		//Function needs to be done or not supported yet
  //GEN_ILLEGAL_ERR = -903,	//Illegal error code
  GEN_SDK_INIT_DONE=-904,
  GEN_SDK_NOT_INIT=-905,
  //GEN_OTHER_ERR = -910,		//Others error code

  DEV_NOT_FIND = -100,		//Device is not present
  //DEV_NOT_AUTHORIZE = -101,	//Device is not authenticated
  //DEV_NOT_INIT = -102,		//Device is not initialized
  DEV_NOT_OPEN = -103,		//Device is not open
  DEV_GET_IMA_FAIL= -104, //Get image fail
  DEV_INIT_FAIL=-105,
  DEV_OPENED=-106,
  DEV_GETLIST_FAIL=-107,
  DEV_GET_DESC_FAIL=-108,
  DEV_OPEN_FAIL=-109,
  DEV_GET_IMA_TIMEOUT=-110,
  DEV_NOT_SUPPORT=-111,
  DEV_LIVE_CAPTURING=-112,
  DEV_LIVE_ENDLIVECAPTURE=-113,
  DEV_GET_HWINFO_FAIL=-114,
  DEV_SETLEDSTATUS_FAIL=-115,
  DEV_GETLEDSTATUS_FAIL=-116,
  DEV_PARAM_ERROR  = -117,
  DEV_MEMORY_ALLOCATED_FAIL  = -118,
  DEV_UNAUTHORIZED = -119,

  ALG_INIT_FAIL=-200,   //Init algorithm fail
  ALG_RAW_TO_BMP_FAIL=-240,   //RAW to BMP fail
  ALG_BIONE_NOT_INIT=-220,    //Algorithm not init
  ALG_EXTRACT_FEATURE_FAIL=-221,   //Extract feature fail
  ALG_GEN_TEMPLATE_FAIL=-222, //creat template fail
  ALG_IMG_QUALITY_LOW=-211,
  TEMPLATE_STORE_FAIL=-230,  
  TEMPLATE_READ_FAIL=-231,    
  TEMPLATE_NOFILE_FAIL=-232,  
  TEMPLATE_WRITE_FAIL=-233,	  
  NO_MORE_ID=-234, 
  IDENTIFY_FAIL=-235,
  FP_High_REPETITION=-236, 
  FP_STORE_FAILED=-237,
  FP_HAS_ENROLLED=-238,
};

#ifdef __cplusplus
extern "C"
{
#endif

/*
  Initialized Aratek FP device .
  * On sucess it return zero , On fail its return -ve number.     
*/
int ARAFPSCAN_GlobalInit (void);

/*
  Release Aratek FP device.  
*/
int ARAFPSCAN_GlobalFree (void);

/*
  Genrate FP Raw Image Data     
*/
int ARAFPSCAN_CaptureRawData (HANDLE nHandle, int nTimeout,unsigned char *pRawData); 
/*
  Genrate BMP data    
*/

int ARAFPSCAN_GetDeviceDescription(int deviceIndex, ARAFP_DevDesc *pDeviceDesc);

int ARAFPSCAN_GetImageInfo(HANDLE nHandle, int *pnWidth, int *pnHeight, int *pnDpi);
int ARAFPSCAN_CaptureBitmapData(HANDLE nHandle, unsigned char *outBmpData);
/*
  Open FP Device  
*/
int ARAFPSCAN_OpenDevice (HANDLE *nHandle, int nIndex);
/*
   Close Device 
*/
int ARAFPSCAN_CloseDevice (HANDLE *nHandle);
/*
   Get the number of connected FP  Device .
*/
int ARAFPSCAN_GetDeviceCount (int *nDeviceCount);
/*
   Convert Raw Data To BMP Data .
*/


int ARAFPSCAN_SetLedStatus(HANDLE nHandle,int nLedIndex,int pStatus);
int ARAFPSCAN_GetFwVersion(HANDLE handle, unsigned char* pulFwVersion);

int ARAFPSCAN_GetLedStatus(HANDLE nHandle,int nLedIndex,int *pStatus);

int ARAFPSCAN_CaptureISOData(HANDLE nHandle, int nTimeout, int FingerPos, int Imgcompressalg, unsigned char *ISOImgData, int *pLenOutput);  

int ARAFPSCAN_CaptureANSIData(HANDLE nHandle, int nTimeout, int FingerPos, int Imgcompressalg, unsigned char *ANSIImgData, int *pLenOutput);  

int ARAFPSCAN_ExtractFeature(HANDLE nHandle, unsigned char cFingerPos, unsigned char *pFeatureData);

int ARAFPSCAN_ExtractANSIFeature(HANDLE nHandle, unsigned char cFingerPos, unsigned char *pFeatureData);

int ARAFPSCAN_ExtractISOFeature(HANDLE nHandle, unsigned char cFingerPos, unsigned char *pFeatureData);

int ARAFPSCAN_ImgQuality(int width, int height, unsigned char *ipImage, int *Quality);

int ARAFPSCAN_SearchFromModule(HANDLE nHandle, unsigned char *userId, unsigned int *matchScore);

int ARAFPSCAN_GetErrorInfo(int nErrorNo, char pszErrorInfo[256]);





int ARAFPSCAN_VerifyExt(HANDLE nHandle, int Security_Level,unsigned char pFeatureData[FEATURE_LENGTH], int dbNumFeature, unsigned char *pDbTemplateData/*[dbFeatureNum*FEATURE_LENGTH]*/, int *sc,int *pResult);
int ARAFPSCAN_GetVersion(unsigned char *versionBuf);

int ARAFPSCAN_Enroll(HANDLE nHandle, unsigned int byTimeout, unsigned char ulCurrentPressTimes, char *userName, char *fingerName);
int ARAFPSCAN_Identify(HANDLE nHandle, int Security_Level, unsigned int byTimeout, char *userName, char *fingerName, int *score);
int ARAFPSCAN_DeleteFinger(HANDLE nHandle, char *userName, char *fingerName);
int ARAFPSCAN_DeleteAllFinger(HANDLE nHandle, char *userName);
int ARAFPSCAN_EnrollListFingers(HANDLE nHandle, char *userName, char *fingerName, int *enrolledNum);
int ARAFPSCAN_RenameFinger(HANDLE nHandle, char *userName, char *oldFingerName, char *newFingerName);


#ifdef __cplusplus
}
#endif


#endif
